==> mingw-w64-ogre3d-13.6.3-1.src.tar.zst: ogre-13.6.3/PlugIns/EXRCodec/src/O_IStream.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef _O_IStream_H__
#define _O_IStream_H__

#include "OgreDataStream.h"
#include <ImfInt64.h>
#include <ImfIO.h>


namespace Ogre {
   
/**
 * Adapter class for feeding OGRE data chunks as input to Imf.
 */
class O_IStream: public Imf::IStream
{
public:

    O_IStream(MemoryDataStream& stream, const char file_name[]):
        IStream (file_name), _stream(stream) {}

    bool    read (char c[], int n) override;
    Imf::Int64   tellg () override;
    void    seekg (Imf::Int64 pos) override;
    void    clear () override;

private:
    MemoryDataStream& _stream;
};

};

#endif

==> mingw-w64-ogre3d-14.3.0-1.src.tar.zst: ogre-14.3.0/PlugIns/EXRCodec/src/O_IStream.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef _O_IStream_H__
#define _O_IStream_H__

#include "OgreDataStream.h"
#include <ImfInt64.h>
#include <ImfIO.h>


namespace Ogre {
   
/**
 * Adapter class for feeding OGRE data chunks as input to Imf.
 */
class O_IStream: public Imf::IStream
{
public:

    O_IStream(MemoryDataStream& stream, const char file_name[]):
        IStream (file_name), _stream(stream) {}

    bool    read (char c[], int n) override;
    uint64_t   tellg () override;
    void    seekg (uint64_t pos) override;
    void    clear () override;

private:
    MemoryDataStream& _stream;
};

};

#endif
